==> cloudcompare_2.10.3.orig.tar.gz: CloudCompare-2.10.3/libs/qCC_db/qCC_db.h <==
//##########################################################################
//#                                                                        #
//#                               QCC_DB                                   #
//#                                                                        #
//#  This program is free software; you can redistribute it and/or modify  #
//#  it under the terms of the GNU Library General Public License as       #
//#  published by the Free Software Foundation; version 2 or later of the  #
//#  License.                                                              #
//#                                                                        #
//#  This program is distributed in the hope that it will be useful,       #
//#  but WITHOUT ANY WARRANTY; without even the implied warranty of        #
//#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          #
//#  GNU General Public License for more details.                          #
//#                                                                        #
//#          COPYRIGHT: EDF R&D / TELECOM ParisTech (ENST-TSI)             #
//#                                                                        #
//##########################################################################

#ifdef QCC_DB_USE_AS_DLL

// The following ifdef block is the standard way of creating macros which make exporting
// from a DLL simpler. All files within this DLL are compiled with the QCC_DB_LIB_EXPORTS
// symbol defined on the command line. this symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see
// QCC_DB_LIB_API functions as being imported from a DLL, whereas this DLL sees symbols
// defined with this macro as being exported.
#ifdef QCC_DB_LIB_EXPORTS

#define QCC_DB_LIB_API __declspec(dllexport)
#else //NOT QCC_DB_LIB_EXPORTS
#define QCC_DB_LIB_API __declspec(dllimport)
#endif //NOT QCC_DB_LIB_EXPORTS

#else //NOT QCC_DB_USE_AS_DLL

#define QCC_DB_LIB_API

#endif //NOT QCC_DB_USE_AS_DLL

==> cloudcompare_2.11.3.orig.tar.gz: CloudCompare-2.11.3/libs/qCC_db/qCC_db.h <==
//##########################################################################
//#                                                                        #
//#                               QCC_DB                                   #
//#                                                                        #
//#  This program is free software; you can redistribute it and/or modify  #
//#  it under the terms of the GNU Library General Public License as       #
//#  published by the Free Software Foundation; version 2 or later of the  #
//#  License.                                                              #
//#                                                                        #
//#  This program is distributed in the hope that it will be useful,       #
//#  but WITHOUT ANY WARRANTY; without even the implied warranty of        #
//#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          #
//#  GNU General Public License for more details.                          #
//#                                                                        #
//#          COPYRIGHT: EDF R&D / TELECOM ParisTech (ENST-TSI)             #
//#                                                                        #
//##########################################################################

#ifndef CC_DB_HEADER
#define CC_DB_HEADER

#include <QtCore/QtGlobal>

#if defined( QCC_DB_LIBRARY_BUILD )
#  define QCC_DB_LIB_API Q_DECL_EXPORT
#else
#  define QCC_DB_LIB_API Q_DECL_IMPORT
#endif

#endif //CC_DB_HEADER
